/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ;
typedef NU8 tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w;
struct tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg {
	FILE* f;
	tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ currentSection;
	tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w err;
};
typedef NU8 tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg;
typedef NU8 tyArray__mXjDD1r0VWLRZmHnQfpVHA[8];
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__stdZsyncio_u412)(FILE** f_p0, NimStringV2 filename_p1, tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg mode_p2, NI bufSize_p3);
static N_INLINE(void, setError__icZrodfiles_u59)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w err_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(NI, readBytes__icZrodfiles_u386)(FILE* f_p0, NU8* a_p1, NI a_p1Len_0, NI start_p2, NI len_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___icZrodfiles_u472)(tyArray__mXjDD1r0VWLRZmHnQfpVHA x_p0, tyArray__mXjDD1r0VWLRZmHnQfpVHA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_u580)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(NI, readBuffer__stdZsyncio_u165)(FILE* f_p0, void* buffer_p1, NI len_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u5518)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, newSeq__stdZsyncio_u571)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_u114)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NimStringV2* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u1694)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* dest_p0, tySequence__9bAGqSvkAaFL9bWjsEPslrFA src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__9bAGqSvkAaFL9bWjsEPslrFA, newSeq__icZic_u7892)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u7902)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NU32* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8080)(tySequence__PXIzfWocnrafGz5p3CP5LA* dest_p0, tySequence__PXIzfWocnrafGz5p3CP5LA src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__PXIzfWocnrafGz5p3CP5LA, newSeq__icZic_u7969)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8109)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__0q9cmhneJEKnQERTpXXdz6Q* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8262)(tySequence__IHUFRsFxZNv7YydiUO2esQ* dest_p0, tySequence__IHUFRsFxZNv7YydiUO2esQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__IHUFRsFxZNv7YydiUO2esQ, newSeq__icZic_u8173)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8288)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI64* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8429)(tySequence__b89aLriiJnVTD186H6zNIgg* dest_p0, tySequence__b89aLriiJnVTD186H6zNIgg src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__b89aLriiJnVTD186H6zNIgg, newSeq__icZic_u8340)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8455)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8615)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* dest_p0, tySequence__hIPTk9aFdaMMVAOzEbnPyqg src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__hIPTk9aFdaMMVAOzEbnPyqg, newSeq__icZic_u8526)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8641)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__7rmdAMLZ8fDd79brQn2ixZA* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8801)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0, tySequence__48JTohSgTy339bRxHzUD8KA src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__48JTohSgTy339bRxHzUD8KA, newSeq__icZic_u8712)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8827)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZpacked95ast_u132)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* dest_p0, tySequence__OxRbUT0qZaZN5UjnqQjGPA src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__OxRbUT0qZaZN5UjnqQjGPA, newSeq__icZpacked95ast_u1305)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZpacked95ast_u1323)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZpacked95ast_u272)(tySequence__ezS5mGPcRfBURJyMgqYVzA* dest_p0, tySequence__ezS5mGPcRfBURJyMgqYVzA src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__ezS5mGPcRfBURJyMgqYVzA, newSeq__icZpacked95ast_u1390)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZpacked95ast_u1408)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__48iPM3yLBKU5nyEuYwJvuQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZpacked95ast_u375)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* dest_p0, tySequence__wW7xkohjuUKO9aMaB0nt9cqA src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__wW7xkohjuUKO9aMaB0nt9cqA, newSeq__icZpacked95ast_u1475)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZpacked95ast_u1493)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__R3ddFrA0G9buJY57Qhf9cTpg* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8922)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* dest_p0, tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, initOrderedTable__icZic_u8892)(NI initialSize_p0, tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* Result);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8940)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u5788)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9084)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* dest_p0, tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, initOrderedTable__icZic_u9054)(NI initialSize_p0, tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* Result);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9102)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9126)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9164)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9202)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u9240)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u3950)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* dest_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__qBes3XzcQQ9cyia9bRwnmbJw, newSeq__icZic_u7631)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9276)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9314)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9370)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI16* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u3779)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u5026)(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u5029)(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9567)(tySequence__YYy1721YAuPF0ajBYHd8Wg* dest_p0, tySequence__YYy1721YAuPF0ajBYHd8Wg src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__YYy1721YAuPF0ajBYHd8Wg, newSeq__icZic_u9478)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9593)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__qPXRCRNQuZLLKto7CIIEzw* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9771)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* dest_p0, tySequence__UODJbvzmu39c3Ho9cqhSk9agQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ, newSeq__icZic_u9660)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9800)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9954)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* dest_p0, tySequence__F1qNdU7m0Czu7Y2q0eksXw src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__F1qNdU7m0Czu7Y2q0eksXw, newSeq__icZic_u9865)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9980)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__6kG8KAxm9aXPdLdlxcxqJJw* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u10164)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* dest_p0, tySequence__r3Kz9breImOXyFFoJ29aBM8Q src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__r3Kz9breImOXyFFoJ29aBM8Q, newSeq__icZic_u10047)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u10190)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__TRK7rrwoha9bbDAdPWsqJMw* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZiclineinfos_u378)(tySequence__orxtl6CusdjXleqrxi67gw* dest_p0, tySequence__orxtl6CusdjXleqrxi67gw src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__orxtl6CusdjXleqrxi67gw, newSeq__icZiclineinfos_u289)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZiclineinfos_u404)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__MaWaKZwaGUqCXKsSK12rVg* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, close__stdZsyncio_u268)(FILE* f_p0);
N_LIB_PRIVATE N_NIMCALL(NI, writeBytes__icZrodfiles_u193)(FILE* f_p0, NU8* a_p1, NI a_p1Len_0, NI start_p2, NI len_p3);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_u512)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ x_p1);
N_LIB_PRIVATE N_NIMCALL(NI, writeBuffer__stdZsyncio_u196)(FILE* f_p0, void* buffer_p1, NI len_p2);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_u81)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NimStringV2 s_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10404)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NU32 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10454)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__0q9cmhneJEKnQERTpXXdz6Q x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10516)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10570)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10624)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__7rmdAMLZ8fDd79brQn2ixZA x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10678)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZpacked95ast_u1565)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZpacked95ast_u1615)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__48iPM3yLBKU5nyEuYwJvuQ x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZpacked95ast_u1665)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__R3ddFrA0G9buJY57Qhf9cTpg x_p1);
static N_INLINE(NI, len__icZic_u10776)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11216)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* x_p1);
static N_INLINE(NI, len__icZic_u11302)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___icZic_u5032)(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* dest_p0, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11730)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11754)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11773)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11792)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u11811)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw s_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11844)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11863)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11900)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI16 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11968)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__qPXRCRNQuZLLKto7CIIEzw x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12018)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12085)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__6kG8KAxm9aXPdLdlxcxqJJw x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12135)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__TRK7rrwoha9bbDAdPWsqJMw x_p1);
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZiclineinfos_u219)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__MaWaKZwaGUqCXKsSK12rVg x_p1);
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_2 = { 2 | NIM_STRLIT_FLAG, "ok" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_3 = {2, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_2};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_4 = { 6 | NIM_STRLIT_FLAG, "tooBig" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_5 = {6, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_6 = { 10 | NIM_STRLIT_FLAG, "cannotOpen" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_7 = {10, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_6};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_8 = { 9 | NIM_STRLIT_FLAG, "ioFailure" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_9 = {9, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_8};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_10 = { 11 | NIM_STRLIT_FLAG, "wrongHeader" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_11 = {11, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_10};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_12 = { 12 | NIM_STRLIT_FLAG, "wrongSection" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_13 = {12, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_12};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_14 = { 14 | NIM_STRLIT_FLAG, "configMismatch" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_15 = {14, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_14};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_16 = { 18 | NIM_STRLIT_FLAG, "includeFileChanged" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_17 = {18, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_16};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__FrEYEpNuSw2loAbEyX5AXw_18 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__FrEYEpNuSw2loAbEyX5AXw_19 = {0, (NimStrPayload*)&TM__FrEYEpNuSw2loAbEyX5AXw_18};
N_LIB_PRIVATE NIM_CONST tyArray__mXjDD1r0VWLRZmHnQfpVHA defaultCookie__icZrodfiles_u58 = {((NU8)0),
((NU8)82),
((NU8)79),
((NU8)68),
((NU8)64),
((NU8)0),
((NU8)0),
((NU8)2)}
;
extern NIM_BOOL nimInErrorMode__system_u4146;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(void, setError__icZrodfiles_u59)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w err_p1) {
	(*f_p0).err = err_p1;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg, open__icZrodfiles_u637)(NimStringV2 filename_p0) {
	tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = open__stdZsyncio_u412(&result.f, filename_p0, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)0), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		setError__icZrodfiles_u59((&result), ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadHeader__icZrodfiles_u244)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyArray__mXjDD1r0VWLRZmHnQfpVHA cookie_p1) {
	tyArray__mXjDD1r0VWLRZmHnQfpVHA thisCookie_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	nimZeroMem((void*)thisCookie_1, sizeof(tyArray__mXjDD1r0VWLRZmHnQfpVHA));
	nimZeroMem((void*)thisCookie_1, sizeof(tyArray__mXjDD1r0VWLRZmHnQfpVHA));
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBytes__icZrodfiles_u386((*f_p0).f, thisCookie_1, 8, ((NI)0), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = eqeq___icZrodfiles_u472(thisCookie_1, cookie_p1);
		if (!!(T11_)) goto LA12_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA12_: ;
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_u580)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSection__icZrodfiles_u567)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ expected_p1) {
	tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ s_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	s_1 = 0;
	loadPrim__icZrodfiles_u580(f_p0, (&s_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !((expected_p1 == s_1));
		if (!(T7_)) goto LA8_;
		T7_ = ((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0));
LA8_: ;
		if (!T7_) goto LA9_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)5));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZrodfiles_u114)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NimStringV2* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		NimStringV2 T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = mnewString(((NI) (lenPrefix_1)));
		eqsink___system_u2700((&(*s_p1)), T11_);
		{
			if (!(((NI32)0) < lenPrefix_1)) goto LA14_;
			{
				NI T18_;
				T18_ = (NI)0;
				T18_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&(*s_p1).p->data[((NI)0)]))), ((*s_p1).len));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!!((T18_ == (*s_p1).len))) goto LA19_;
				setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA19_: ;
		}
LA14_: ;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u7734)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u7770)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)16));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)16)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u7825)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__stdZsyncio_u571(((NI) (lenPrefix_1)));
		eqsink___system_u5518((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZrodfiles_u114(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u7902)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NU32* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u7861)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__9bAGqSvkAaFL9bWjsEPslrFA T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u7892(((NI) (lenPrefix_1)));
		eqsink___icZic_u1694((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u7902(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8109)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__0q9cmhneJEKnQERTpXXdz6Q* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA7_;
		loadPrim__icZic_u7902(f_p0, (&(*x_p1).Field0));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		loadPrim__icZrodfiles_u114(f_p0, (&(*x_p1).Field1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u7938)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__PXIzfWocnrafGz5p3CP5LA* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__PXIzfWocnrafGz5p3CP5LA T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u7969(((NI) (lenPrefix_1)));
		eqsink___icZic_u8080((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u8109(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8288)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI64* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u8142)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__IHUFRsFxZNv7YydiUO2esQ* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__IHUFRsFxZNv7YydiUO2esQ T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u8173(((NI) (lenPrefix_1)));
		eqsink___icZic_u8262((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u8288(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8455)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u8309)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__b89aLriiJnVTD186H6zNIgg* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__b89aLriiJnVTD186H6zNIgg T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u8340(((NI) (lenPrefix_1)));
		eqsink___icZic_u8429((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u8455(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8641)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__7rmdAMLZ8fDd79brQn2ixZA* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)12)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u8495)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__hIPTk9aFdaMMVAOzEbnPyqg* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__hIPTk9aFdaMMVAOzEbnPyqg T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u8526(((NI) (lenPrefix_1)));
		eqsink___icZic_u8615((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u8641(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8827)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u8681)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__48JTohSgTy339bRxHzUD8KA* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__48JTohSgTy339bRxHzUD8KA T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u8712(((NI) (lenPrefix_1)));
		eqsink___icZic_u8801((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u8827(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZpacked95ast_u1323)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZpacked95ast_u1274)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__OxRbUT0qZaZN5UjnqQjGPA* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__OxRbUT0qZaZN5UjnqQjGPA T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZpacked95ast_u1305(((NI) (lenPrefix_1)));
		eqsink___icZpacked95ast_u132((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZpacked95ast_u1323(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZpacked95ast_u1408)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__48iPM3yLBKU5nyEuYwJvuQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZpacked95ast_u1359)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__ezS5mGPcRfBURJyMgqYVzA* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__ezS5mGPcRfBURJyMgqYVzA T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZpacked95ast_u1390(((NI) (lenPrefix_1)));
		eqsink___icZpacked95ast_u272((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZpacked95ast_u1408(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZpacked95ast_u1493)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__R3ddFrA0G9buJY57Qhf9cTpg* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)12)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZpacked95ast_u1444)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__wW7xkohjuUKO9aMaB0nt9cqA* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__wW7xkohjuUKO9aMaB0nt9cqA T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZpacked95ast_u1475(((NI) (lenPrefix_1)));
		eqsink___icZpacked95ast_u375((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZpacked95ast_u1493(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u8940)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)136));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)136)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadOrderedTable__icZic_u8864)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw T11_;
		nimZeroMem((void*)(&T11_), sizeof(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw));
		initOrderedTable__icZic_u8892(((NI) (lenPrefix_1)), (&T11_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___icZic_u8922((&(*s_p1)), (&T11_));
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw x_1;
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					nimZeroMem((void*)(&x_1), sizeof(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw));
					nimZeroMem((void*)(&x_1), sizeof(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw));
					loadPrim__icZic_u8940(f_p0, (&x_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					X5BX5Deq___icZic_u5788(s_p1, x_1.id, (&x_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9126)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9164)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9202)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9276)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u9240)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__qBes3XzcQQ9cyia9bRwnmbJw T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u7631(((NI) (lenPrefix_1)));
		eqsink___icZic_u3950((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u9276(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9314)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9370)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI16* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)2)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9102)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA7_;
		loadPrim__icZic_u8827(f_p0, (&(*x_p1).id));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		loadPrim__icZic_u9126(f_p0, (&(*x_p1).kind));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA15_;
		loadPrim__icZic_u9164(f_p0, (&(*x_p1).callConv));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA15_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		loadPrim__icZic_u9202(f_p0, (&(*x_p1).flags));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA19_: ;
	{
		if (!NIM_TRUE) goto LA23_;
		loadSeq__icZic_u9240(f_p0, (&(*x_p1).types));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA23_: ;
	{
		if (!NIM_TRUE) goto LA27_;
		loadPrim__icZic_u9314(f_p0, (&(*x_p1).n));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA27_: ;
	{
		if (!NIM_TRUE) goto LA31_;
		loadPrim__icZic_u9276(f_p0, (&(*x_p1).sym));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA31_: ;
	{
		if (!NIM_TRUE) goto LA35_;
		loadPrim__icZic_u9276(f_p0, (&(*x_p1).owner));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA35_: ;
	{
		if (!NIM_TRUE) goto LA39_;
		loadPrim__icZic_u8288(f_p0, (&(*x_p1).size));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA39_: ;
	{
		if (!NIM_TRUE) goto LA43_;
		loadPrim__icZic_u9370(f_p0, (&(*x_p1).align));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA43_: ;
	{
		if (!NIM_TRUE) goto LA47_;
		loadPrim__icZic_u9370(f_p0, (&(*x_p1).paddingAtEnd));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA47_: ;
	{
		if (!NIM_TRUE) goto LA51_;
		loadPrim__icZic_u9276(f_p0, (&(*x_p1).typeInst));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA51_: ;
	{
		if (!NIM_TRUE) goto LA55_;
		loadPrim__icZic_u8827(f_p0, (&(*x_p1).nonUniqueId));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA55_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadOrderedTable__icZic_u9026)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw T11_;
		nimZeroMem((void*)(&T11_), sizeof(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw));
		initOrderedTable__icZic_u9054(((NI) (lenPrefix_1)), (&T11_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___icZic_u9084((&(*s_p1)), (&T11_));
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ x_1;
					NI32 T16_;
					tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ blitTmp_1;
					if (!(res_1 < lenPrefix_1)) goto LA14;
					nimZeroMem((void*)(&x_1), sizeof(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ));
					i_1 = res_1;
					nimZeroMem((void*)(&x_1), sizeof(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ));
					loadPrim__icZic_u9102(f_p0, (&x_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					T16_ = (NI32)0;
					T16_ = x_1.id;
					nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ));
					blitTmp_1 = x_1;
					eqwasMoved___icZic_u5026((&x_1));
					X5BX5Deq___icZic_u3779(s_p1, T16_, (&blitTmp_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					res_1 += ((NI)1);
					{
						LA15_:;
					}
					{
						eqdestroy___icZic_u5029((&x_1));
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9593)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__qPXRCRNQuZLLKto7CIIEzw* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)16));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)16)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u9447)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__YYy1721YAuPF0ajBYHd8Wg* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__YYy1721YAuPF0ajBYHd8Wg T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u9478(((NI) (lenPrefix_1)));
		eqsink___icZic_u9567((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u9593(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9800)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA7_;
		loadPrim__icZic_u9276(f_p0, (&(*x_p1).key));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		loadPrim__icZic_u9276(f_p0, (&(*x_p1).sym));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA15_;
		loadSeq__icZic_u9240(f_p0, (&(*x_p1).concreteTypes));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u9629)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__UODJbvzmu39c3Ho9cqhSk9agQ T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u9660(((NI) (lenPrefix_1)));
		eqsink___icZic_u9771((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u9800(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u9980)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__6kG8KAxm9aXPdLdlxcxqJJw* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)20));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)20)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u9834)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__F1qNdU7m0Czu7Y2q0eksXw* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__F1qNdU7m0Czu7Y2q0eksXw T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u9865(((NI) (lenPrefix_1)));
		eqsink___icZic_u9954((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u9980(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u10190)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__TRK7rrwoha9bbDAdPWsqJMw* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)24));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)24)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZic_u10016)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__r3Kz9breImOXyFFoJ29aBM8Q* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__r3Kz9breImOXyFFoJ29aBM8Q T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u10047(((NI) (lenPrefix_1)));
		eqsink___icZic_u10164((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZic_u10190(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZic_u10242)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPrim__icZiclineinfos_u404)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__MaWaKZwaGUqCXKsSK12rVg* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) (x_p1)), ((NI)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)12)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, loadSeq__icZiclineinfos_u258)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__orxtl6CusdjXleqrxi67gw* s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	lenPrefix_1 = ((NI32)0);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = readBuffer__stdZsyncio_u165((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA8_: ;
	{
		tySequence__orxtl6CusdjXleqrxi67gw T11_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZiclineinfos_u289(((NI) (lenPrefix_1)));
		eqsink___icZiclineinfos_u378((&(*s_p1)), T11_);
		{
			NI32 i_1;
			NI32 res_1;
			i_1 = (NI32)0;
			res_1 = ((NI32)0);
			{
				while (1) {
					if (!(res_1 < lenPrefix_1)) goto LA14;
					i_1 = res_1;
					loadPrim__icZiclineinfos_u404(f_p0, (&(*s_p1).p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, close__icZrodfiles_u635)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	close__stdZsyncio_u268((*f_p0).f);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___icZrodfiles_u51)(tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_3;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_5;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)2):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_7;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_9;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)4):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_11;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)5):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_13;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)6):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_15;
	}
	break;
	case ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)7):
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_17;
	}
	break;
	default:
	{
		result = TM__FrEYEpNuSw2loAbEyX5AXw_19;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg, create__icZrodfiles_u606)(NimStringV2 filename_p0) {
	tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = open__stdZsyncio_u412(&result.f, filename_p0, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)1), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		setError__icZrodfiles_u59((&result), ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeHeader__icZrodfiles_u142)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyArray__mXjDD1r0VWLRZmHnQfpVHA cookie_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBytes__icZrodfiles_u193((*f_p0).f, cookie_p1, 8, ((NI)0), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_u512)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSection__icZrodfiles_u498)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_RodSection__Xi2OgRbRir9cb6dpZY9bGVdQ s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	(*f_p0).currentSection = s_p1;
	storePrim__icZrodfiles_u512(f_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZrodfiles_u81)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NimStringV2 s_p1) {
	NI32 lenPrefix_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(((NI)2147483647) <= s_p1.len)) goto LA7_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA7_: ;
	lenPrefix_1 = ((NI32) (s_p1.len));
	{
		NI T11_;
		T11_ = (NI)0;
		T11_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T11_ == ((NI)4)))) goto LA12_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA9_;
LA12_: ;
	{
		{
			if (!!((s_p1.len == ((NI)0)))) goto LA17_;
			{
				NI T21_;
				T21_ = (NI)0;
				T21_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&s_p1.p->data[((NI)0)]))), (s_p1.len));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!!((T21_ == s_p1.len))) goto LA22_;
				setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA22_: ;
		}
LA17_: ;
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10289)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10306)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)16));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)16)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10338)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZrodfiles_u81(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10404)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NU32 x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10371)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__9bAGqSvkAaFL9bWjsEPslrFA s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u10404(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10454)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__0q9cmhneJEKnQERTpXXdz6Q x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA7_;
		storePrim__icZic_u10404(f_p0, x_p1.Field0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		storePrim__icZrodfiles_u81(f_p0, x_p1.Field1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10421)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__PXIzfWocnrafGz5p3CP5LA s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u10454(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10516)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI64 x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10483)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__IHUFRsFxZNv7YydiUO2esQ s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u10516(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10570)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10537)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__b89aLriiJnVTD186H6zNIgg s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u10570(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10624)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__7rmdAMLZ8fDd79brQn2ixZA x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)12)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10591)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__hIPTk9aFdaMMVAOzEbnPyqg s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u10624(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u10678)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32 x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u10645)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__48JTohSgTy339bRxHzUD8KA s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u10678(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZpacked95ast_u1565)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZpacked95ast_u1532)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__OxRbUT0qZaZN5UjnqQjGPA s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZpacked95ast_u1565(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZpacked95ast_u1615)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__48iPM3yLBKU5nyEuYwJvuQ x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZpacked95ast_u1582)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__ezS5mGPcRfBURJyMgqYVzA s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZpacked95ast_u1615(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZpacked95ast_u1665)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__R3ddFrA0G9buJY57Qhf9cTpg x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)12)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZpacked95ast_u1632)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__wW7xkohjuUKO9aMaB0nt9cqA s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZpacked95ast_u1665(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, len__icZic_u10776)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0) {
	NI result;
	result = (*t_p0).counter;
	return result;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0) {
	NIM_BOOL result;
	result = !((hcode_p0 == ((NI)0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11216)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) (x_p1)), ((NI)136));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)136)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeOrderedTable__icZic_u10715)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = len__icZic_u10776(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = (NI)0;
	T10_ = len__icZic_u10776(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI32 __1;
			tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw v_1;
			NI L_1;
			__1 = (NI32)0;
			nimZeroMem((void*)(&v_1), sizeof(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw));
			L_1 = len__icZic_u10776(s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				NI h_1;
				if (!(((NI)0) < (*s_p1).counter)) goto LA20_;
				h_1 = (*s_p1).first;
				{
					while (1) {
						NI nxt_1;
						if (!(((NI)0) <= h_1)) goto LA23;
						nxt_1 = (*s_p1).data.p->data[h_1].Field1;
						{
							NIM_BOOL T26_;
							T26_ = (NIM_BOOL)0;
							T26_ = isFilled__pureZcollectionsZtables_u32((*s_p1).data.p->data[h_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T26_) goto LA27_;
							__1 = (*s_p1).data.p->data[h_1].Field2;
							v_1 = (*s_p1).data.p->data[h_1].Field3;
							storePrim__icZic_u11216(f_p0, (&v_1));
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						}
LA27_: ;
						h_1 = nxt_1;
					} LA23: ;
				}
			}
LA20_: ;
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, len__icZic_u11302)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0) {
	NI result;
	result = (*t_p0).counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11754)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11773)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11792)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11844)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)8)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u11811)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u11844(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11863)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI32 x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)4)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11900)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, NI16 x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)2)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11730)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA7_;
		storePrim__icZic_u10678(f_p0, (*x_p1).id);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		storePrim__icZic_u11754(f_p0, (*x_p1).kind);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA15_;
		storePrim__icZic_u11773(f_p0, (*x_p1).callConv);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA15_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		storePrim__icZic_u11792(f_p0, (*x_p1).flags);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA19_: ;
	{
		if (!NIM_TRUE) goto LA23_;
		storeSeq__icZic_u11811(f_p0, (*x_p1).types);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA23_: ;
	{
		if (!NIM_TRUE) goto LA27_;
		storePrim__icZic_u11863(f_p0, (*x_p1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA27_: ;
	{
		if (!NIM_TRUE) goto LA31_;
		storePrim__icZic_u11844(f_p0, (*x_p1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA31_: ;
	{
		if (!NIM_TRUE) goto LA35_;
		storePrim__icZic_u11844(f_p0, (*x_p1).owner);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA35_: ;
	{
		if (!NIM_TRUE) goto LA39_;
		storePrim__icZic_u10516(f_p0, (*x_p1).size);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA39_: ;
	{
		if (!NIM_TRUE) goto LA43_;
		storePrim__icZic_u11900(f_p0, (*x_p1).align);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA43_: ;
	{
		if (!NIM_TRUE) goto LA47_;
		storePrim__icZic_u11900(f_p0, (*x_p1).paddingAtEnd);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA47_: ;
	{
		if (!NIM_TRUE) goto LA51_;
		storePrim__icZic_u11844(f_p0, (*x_p1).typeInst);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA51_: ;
	{
		if (!NIM_TRUE) goto LA55_;
		storePrim__icZic_u10678(f_p0, (*x_p1).nonUniqueId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA55_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeOrderedTable__icZic_u11241)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = len__icZic_u11302(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = (NI)0;
	T10_ = len__icZic_u11302(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ v_1;
			NI32 __1;
			NI L_1;
			nimZeroMem((void*)(&v_1), sizeof(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ));
			__1 = (NI32)0;
			L_1 = len__icZic_u11302(s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			{
				NI h_1;
				if (!(((NI)0) < (*s_p1).counter)) goto LA21_;
				h_1 = (*s_p1).first;
				{
					while (1) {
						NI nxt_1;
						if (!(((NI)0) <= h_1)) goto LA24;
						nxt_1 = (*s_p1).data.p->data[h_1].Field1;
						{
							NIM_BOOL T27_;
							T27_ = (NIM_BOOL)0;
							T27_ = isFilled__pureZcollectionsZtables_u32((*s_p1).data.p->data[h_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							if (!T27_) goto LA28_;
							__1 = (*s_p1).data.p->data[h_1].Field2;
							eqcopy___icZic_u5032((&v_1), (&(*s_p1).data.p->data[h_1].Field3));
							storePrim__icZic_u11730(f_p0, (&v_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						}
LA28_: ;
						h_1 = nxt_1;
					} LA24: ;
				}
			}
LA21_: ;
			{
				LA18_:;
			}
			{
				eqdestroy___icZic_u5029((&v_1));
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u11968)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__qPXRCRNQuZLLKto7CIIEzw x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)16));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)16)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u11935)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__YYy1721YAuPF0ajBYHd8Wg s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u11968(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12018)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA7_;
		storePrim__icZic_u11844(f_p0, (*x_p1).key);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		storePrim__icZic_u11844(f_p0, (*x_p1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA15_;
		storeSeq__icZic_u11811(f_p0, (*x_p1).concreteTypes);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u11985)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__UODJbvzmu39c3Ho9cqhSk9agQ s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u12018(f_p0, (&s_p1.p->data[i_1]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12085)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__6kG8KAxm9aXPdLdlxcxqJJw x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)20));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)20)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u12052)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__F1qNdU7m0Czu7Y2q0eksXw s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u12085(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12135)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__TRK7rrwoha9bbDAdPWsqJMw x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)24));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)24)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZic_u12102)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__r3Kz9breImOXyFFoJ29aBM8Q s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZic_u12135(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZic_u12168)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)1)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storePrim__icZiclineinfos_u219)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tyTuple__MaWaKZwaGUqCXKsSK12rVg x_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&x_p1))), ((NI)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T7_ == ((NI)12)))) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeSeq__icZiclineinfos_u186)(tyObject_RodFile__k9byU8W8yLbzhHX06zPe4zg* f_p0, tySequence__orxtl6CusdjXleqrxi67gw s_p1) {
	NI32 lenPrefix_1;
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*f_p0).err == ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)0)))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI T7_;
		T7_ = s_p1.len;
		if (!(((NI)2147483647) <= T7_)) goto LA8_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA8_: ;
	T10_ = s_p1.len;
	lenPrefix_1 = ((NI32) (T10_));
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = writeBuffer__stdZsyncio_u196((*f_p0).f, ((void*) ((&lenPrefix_1))), ((NI)4));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T13_ == ((NI)4)))) goto LA14_;
		setError__icZrodfiles_u59(f_p0, ((tyEnum_RodFileError__thsDMuvD9chwjXn4dQReB1w)3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA11_;
LA14_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI T18_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T18_ = s_p1.len;
			colontmp_ = T18_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i_1 = i_2;
					storePrim__icZiclineinfos_u219(f_p0, s_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA20: ;
			}
		}
	}
LA11_: ;
	}BeforeRet_: ;
}
